@@ -11,7 +11,8 @@
 
 #include "ui_loadpage.h"
 
-namespace Kross {
+namespace Kross
+{
 class Action;
 }
 
@@ -31,7 +32,7 @@ Q_SIGNALS:
 
 private:
     Ui::LoadPage ui;
-    QVector< QPair< QObject *, QString > > m_exportedObjects;
+    QVector<QPair<QObject *, QString>> m_exportedObjects;
     Kross::Action *m_action = nullptr;
 };
 
