@@ -1,7 +1,7 @@
 /*
-    SPDX-FileCopyrightText: 2009 Volker Krause <vkrause@kde.org>
+SPDX-FileCopyrightText: 2009 Volker Krause <vkrause@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "dialog.h"
@@ -11,17 +11,17 @@
 
 #include <KAboutData>
 #include <QApplication>
-#include <QUrl>
 #include <QDebug>
+#include <QUrl>
 
 #include <KDBusService>
 #include <KLocalizedString>
-#include <stdio.h>
 #include <iostream>
+#include <stdio.h>
 
 #include <KCrash>
-#include <QCommandLineParser>
 #include <QCommandLineOption>
+#include <QCommandLineParser>
 #include <QIcon>
 
 int main(int argc, char **argv)
@@ -42,16 +42,18 @@ int main(int argc, char **argv)
                          QStringLiteral("https://community.kde.org/KDE_PIM/Akonadi"));
     aboutData.addAuthor(i18n("Volker Krause"), i18n("Author"), QStringLiteral("vkrause@kde.org"));
     aboutData.addAuthor(i18n("Laurent Montel"), QString(), QStringLiteral("montel@kde.org"));
-
+    aboutData.setProductName(QByteArrayLiteral("Akonadi/Account Wizard"));
     app.setOrganizationDomain(QStringLiteral("kde.org"));
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kontact")));
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
-    parser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("type"), i18n("Only offer accounts that support the given type."), QStringLiteral("type")));
-    parser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("assistant"), i18n("Run the specified assistant."), QStringLiteral("assistant")));
-    parser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("package"), i18n("unpack fullpath on startup and launch that assistant"), QStringLiteral("fullpath")));
-    parser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("assistants"), i18n("Returns types of assistants")));
-
+    parser.addOption(
+        QCommandLineOption(QStringList() << QStringLiteral("type"), i18n("Only offer accounts that support the given type."), QStringLiteral("type")));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("assistant"), i18n("Run the specified assistant."), QStringLiteral("assistant")));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("package"),
+                                        i18n("unpack fullpath on startup and launch that assistant"),
+                                        QStringLiteral("fullpath")));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("assistants"), i18n("Returns types of assistants")));
 
     aboutData.setupCommandLine(&parser);
     parser.process(app);
